@@ -2,6 +2,7 @@ import __main__
 import fileinput
 import re
 
+path = __main__.os.path.abspath(__main__.os.getcwd()) 
 
 def get_version_unix(project_type):
     retrieve_ver_command = ''
@@ -23,19 +24,53 @@ def get_version_unix(project_type):
             
 def get_version(filename):
     result = 1
-    version_string = ''  
+    version_string = ''
+    version_code = ''  
     versionstr = ''
-    if __main__.debug == 1:
-        print("File searched for version number: ", filename)
+    
+    global path
+    
     if __main__.os.path.exists(filename):
         with open(filename) as origin_file:
             for line in origin_file:
-                if re.search(r'version', line):
+                if __main__.arch_type == 'npm' and re.search(r'version"\s*:', line):
                     result = 0
                     versionstr = line
+                    break
+                if __main__.arch_type == 'gradle' and re.search(r'version =', line):
+                    result = 0
+                    versionstr = line
+                    break     
+                if __main__.arch_type == 'gradle' and re.search(r'versionName', line):
+                    result = 0
+                    versionstr = line
+                if __main__.arch_type == 'gradle' and re.search(r'versionCode', line):
+                    result = 0
+                    version_code = line 
+                if __main__.arch_type == 'maven' and re.search(r'<version>', line):
+                    result = 0
+                    versionstr = line
+                    break                
+                if __main__.arch_type == 'flutter' and re.search(r'version:', line):
+                    result = 0
+                    versionstr = line
+                    break                
+                if __main__.arch_type == 'dotnet' and re.search(r'<AssemblyVersion>', line):
+                    result = 0
+                    versionstr = line
+                    break                    
+                if __main__.arch_type == 'netcore' and re.search(r'<AssemblyVersion>', line):
+                    result = 0
+                    versionstr = line
+                    break                    
+
     else:
         print("Could not find file with version number")
         return __main__.sys.exit(2)
+    
+    if __main__.debug == 1:
+        print("File searched for version number: ", filename)
+        print("Version string: ", versionstr)
 
     if __main__.arch_type == 'npm':
         print("Architecture::: Typescript/Javascript: NPM build")
@@ -45,19 +80,29 @@ def get_version(filename):
         version_string = version_string.strip() 
             
     elif __main__.arch_type == 'gradle':
-        print("Architecture::: Java : Gradle build")
-        strip_version = versionstr.strip()
-        split_version = strip_version.split("=")
-        version_string = re.sub("[']", '', split_version[1].strip())
+        java_android_build_file = __main__.os.path.join(path, 'app','build.gradle')
+        if __main__.os.path.exists(java_android_build_file):
+            print("Architecture::: Java Android: Gradle build")
+            strip_version = versionstr.strip()
+            split_version = strip_version.split(" ")
+            version_string = re.sub('["]', '', split_version[1].strip())
+            
+            strip_versionCode = version_code.strip()
+            split_version_code = strip_versionCode.split(" ")
+            version_string = version_string + "+" + split_version_code[1].strip()
+            
+        else:
+            print("Architecture::: Java : Gradle build")
+            strip_version = versionstr.strip()
+            split_version = strip_version.split("=")
+            version_string = re.sub("[']", '', split_version[1].strip())
         
         
     elif __main__.arch_type == 'flutter':
         print("Architecture::: Flutter")
         strip_version = versionstr.strip()
-        split_version = strip_version.split("+")
-        versionCode, versionName = split_version
-        versionCode = re.sub("[']", '', versionCode.strip())
-        versionName = re.sub("[']", '', versionName.strip())
+        split_version = strip_version.split(" ")
+        version_string = re.sub("[']", '', split_version[1].strip())
     
     elif __main__.arch_type == 'maven':
         print("Architecture::: Java : Maven build")
@@ -85,17 +130,38 @@ def process_version(versionstr):
     patch = 0 
     build = 0
     
+    global path
+    
+    versionCode = 0
+    
     current_version = ''
     prelease_version = ''
     version_lst = []
     new_version = ''
     
-    if versionstr == '':
+    if __main__.debug == 1:
+        print("Version string:: Process Version:: ", versionstr)
+    
+    if __main__.arch_type == 'flutter':
+        version_str, versionCode = versionstr.split("+") 
+        versionCode = int(versionCode) + 1
+    elif __main__.arch_type == 'gradle':
+        java_android_build_file = __main__.os.path.join(path, 'app', 'build.gradle')
+        if __main__.os.path.exists(java_android_build_file):
+            version_str, versionCode = versionstr.split("+")
+            versionCode = int(versionCode) + 1
+        else:
+            version_str = versionstr
+    else: 
+        version_str = versionstr
+
+    
+    if version_str == '':
         print("No version number detected.")
         return __main__.sys.exit(2)    
     # Semantic version standard A pre-release version MAY be denoted by appending a hyphen and a series of dot separated identifiers 
     # immediately following the patch version.
-    check_prerelease = versionstr.split("-") 
+    check_prerelease = version_str.split("-") 
     if len(check_prerelease) == 1:
         current_version = check_prerelease[0]
     else:
@@ -143,6 +209,13 @@ def process_version(versionstr):
         
     if prelease_version != '' and __main__.change_type == 'prerelease':
         new_version = new_version + '-' + prelease_version
+    
+    if __main__.arch_type == 'flutter':
+        new_version = new_version + "+" + str(versionCode)
+    elif __main__.arch_type == 'gradle':
+        java_android_build_file = __main__.os.path.join(path, 'app', 'build.gradle')
+        if __main__.os.path.exists(java_android_build_file):
+            new_version = new_version + "+" + str(versionCode)
                     
     return new_version      
         
@@ -150,12 +223,12 @@ def process_version(versionstr):
             
         
 def replace_version(filename, search_text, replacement_text):
-    with fileinput.FileInput(filename, inplace=True, backup='.bak') as file:
+    with fileinput.FileInput(filename, inplace=True, backup='') as file:
         for line in file:
             print(line.replace(search_text, replacement_text), end='')  
             
 def change_version_file(filepath, version, newversion):
-    path = __main__.os.path.abspath(__main__.os.getcwd()) 
+    global path
     if __main__.debug == 1:
         print("Old version: ", version)
         print("New version: ", newversion)
@@ -176,8 +249,14 @@ def change_version_file(filepath, version, newversion):
     if __main__.arch_type == 'gradle':
         java_android_build_file = __main__.os.path.join(path, 'app/build.gradle')
         if __main__.os.path.exists(java_android_build_file):
-            test = 1
-            ## update versionCode and versionName
+            ovn, ovc = version.split("+")
+            nvn, nvc = newversion.split("+")
+            old_version_name = "versionName \"{}\"".format(ovn)
+            new_version_name = "versionName \"{}\"".format(nvn)
+            old_version_code = "versionCode {}".format(ovc)
+            new_version_code = "versionCode {}".format(nvc)
+            replace_version(filepath, old_version_name, new_version_name)
+            replace_version(filepath, old_version_code, new_version_code)
         else:
             old_version = "version = '{}'".format(version)
             new_version = "version = '{}'".format(newversion)
@@ -197,7 +276,7 @@ def change_manifest(v, dv):
     ## Retreive version number manifest
     ## grep "version\s*=\s*" manifest.yml  ## To-do Refactor to use this 
     
-    path = __main__.os.path.abspath(__main__.os.getcwd()) 
+    global path
     file_path = __main__.os.path.join(path, 'manifest.yml')
     
     old_version = "version: {}".format(v)
@@ -219,7 +298,7 @@ def modify_version():
     version_format = ''
     version_file = ''
 
-    path = __main__.os.path.abspath(__main__.os.getcwd())    
+    global path   
     if __main__.debug == 1:
         print("Working directory: ",path)
     
